<?php
/**
 * experoner functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package experoner
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

if ( ! function_exists( 'experoner_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function experoner_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on experoner , use a find and replace
		 * to change 'experoner' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'experoner', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( "custom-background");
		add_theme_support( "wp-block-styles" );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "html5") ;
		add_theme_support( "custom-logo"); 
		add_theme_support( "custom-header" );
		add_theme_support( "align-wide" );


		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'experoner' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'experoner_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'experoner_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $experoner_content_width
 */

function experoner_content_width() {
	$GLOBALS['experoner_content_width'] = apply_filters( 'experoner_content_width', 640 );
}
add_action( 'after_setup_theme', 'experoner_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function experoner_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'experoner' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'experoner' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'experoner' ),
			'id'            => 'footer1',
			'description'   => esc_html__( 'Add widgets here.', 'experoner' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'experoner_widgets_init' );

function experoner_wpdocs_setup_theme() {
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 600, 350, true );
}
add_action( 'after_setup_theme', 'experoner_wpdocs_setup_theme' );


if ( ! function_exists( 'experoner_excerpt_length' ) ) :
	function experoner_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}
		$length	= get_theme_mod( 'experoner_excerpt_length', 30 );

		return absint( $length );
	}
endif; //experoner_excerpt_length
add_filter( 'excerpt_length', 'experoner_excerpt_length', 999 );


// Add custom meta box
add_action("add_meta_boxes", "experoner_add_sidebar_meta_box");
function experoner_add_sidebar_meta_box()
{
	$post_types = get_post_type();
    add_meta_box("sidebar-meta-box", "Custom Meta Box","experoner_sidebar_meta_box_markup", $post_types, "normal", "high", null);
}

function experoner_sidebar_meta_box_markup($object){
   ?>
   		<table class="admin_sidebar_select">
   			<tr><td><label><h2 class="custom_meta">Sidebar</h2></label></td></tr>
		   	<tr>
		   		<td>
		   			<label for="no_sidebar">		   				
		   				<input type="radio" name="sidebar_select" id="no_sidebar" class="no_sidebar" value="no_sidebar" <?php if(get_post_meta($object->ID,'sidebar_select',true)=='no_sidebar'){echo "checked";}?>>
			   				<img src="<?php echo esc_url(get_template_directory_uri()) . '/img/full.png' ?>">
			   			</input>
		   			</label>
		   			<label for="left_sidebar">
		   				<input type="radio" name="sidebar_select" id="left_sidebar" class="left_sidebar" value="left_sidebar" <?php if(get_post_meta($object->ID,'sidebar_select',true)=='left_sidebar'){echo "checked";}?>>
		   					<img src="<?php echo esc_url(get_template_directory_uri()) . '/img/left.png' ?>">
		   				</input>
		   			</label>
		   			<label for="right_sidebar">			   				
		   				<input type="radio" name="sidebar_select" id="right_sidebar" class="right_sidebar" value="right_sidebar" <?php if(get_post_meta($object->ID,'sidebar_select',true)=='right_sidebar'){echo "checked";}?>>
		   					<img src="<?php echo esc_url(get_template_directory_uri()) . '/img/right.png' ?>">
		   				</input>
		   			</label>			
		   		</td>
		   	</tr>
		   	<tr><td><label><h2 class="custom_meta">Breadcrumb</h2></label></td></tr>
		   	<tr>
		   		<td>
		   			<label for="breadcrumb_select">
		   				<input type="radio" name="breadcrumb_select" id="breadcrumb_select" value="yes" <?php if(get_post_meta($object->ID,'breadcrumb_select',true)=='yes'){echo "checked";}?>>Yes 
		   				<input type="radio" name="breadcrumb_select" id="breadcrumb_select" value="no" <?php if(get_post_meta($object->ID,'breadcrumb_select',true)=='no'){echo "checked";}?>>No
		   			</label>
		   		</td>
		   	</tr>
   		</table>
   <?php   
} 

add_action( 'save_post','experoner_save_sidebar_meta_box_data');
function experoner_save_sidebar_meta_box_data( $post_id ) {
	if(isset($_REQUEST['breadcrumb_select'])){
		$breadcrumb_select = sanitize_text_field( wp_unslash($_REQUEST['breadcrumb_select'] ));
		update_post_meta($post_id,'breadcrumb_select',$breadcrumb_select);
	}
	if(isset($_REQUEST['sidebar_select'])){
		$sidebar_select = sanitize_text_field( wp_unslash($_REQUEST['sidebar_select'] ));
		update_post_meta($post_id,'sidebar_select',$sidebar_select);	
	}
}

function experoner_our_team_slider(){
	?>
	<section id="breadcrumb-section" class="breadcrumb-area breadcrumb-centerc">
		<div class="breadcrumb-content">
			<div class="breadcrumb-heading">
				<h1><?php  experoner_breadcrumb_title();	?></h1>
			</div>
			<ol class="breadcrumb-list">
				<li><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><i class="fa fa-home"></i></a></li>
				<li>
					<?php experoner_breadcrumb_title();	?>
				</li>
			</ol>
		</div> 
	</section>
	<?php
}

/**
 * Enqueue scripts and styles.
 */
function experoner_scripts() {
	wp_enqueue_script('jquery', false, array(), false, false);
	wp_enqueue_style( 'experoner-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'experoner-style', 'rtl', 'replace' );

	wp_enqueue_script( 'experoner-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'experoner-owl_slider', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array(), _S_VERSION, true );
	wp_enqueue_script( 'experoner-owl_slider-js', get_template_directory_uri() . '/assets/js/owl_slider.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style( 'fontawesome-css', esc_url(get_template_directory_uri()).'/assets/fontawesome/css/font-awesome.css' , array(), _S_VERSION );
	wp_enqueue_style( 'theme-css', esc_url(get_template_directory_uri()).'/assets/css/theme.css' , array(), _S_VERSION );
	wp_enqueue_style( 'owl-carousel-min-css', esc_url(get_template_directory_uri()).'/assets/css/owl.carousel.min.css' , array(), _S_VERSION );
	wp_enqueue_style( 'owl-carousel_theme-min-css', esc_url(get_template_directory_uri()).'/assets/css/owl.theme.min.css' , array(), _S_VERSION );
}
add_action( 'wp_enqueue_scripts', 'experoner_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Customizer Css additions.
 */
require get_template_directory() . '/inc/customizer_css.php';

require get_template_directory() . '/inc/customizer-control.php';

require get_parent_theme_file_path( '/inc/about.php' );

require_once get_template_directory() . '/framework/wtb-required-plugins.php';

require get_template_directory() . '/framework/index.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

function experoner_main_js() {
    wp_enqueue_script( 'main-js', get_theme_file_uri( '/assets/js/owl_slider.js' ), array(), '1.0', true );
    // Localize the script with new data and pass php variables to JS.
    $main_js_data = array(
        /* FOR LATER USE. */
        'autoplay' => get_theme_mod('experoner_ourteam_autoplay', true),
        'autoplayspped' => get_theme_mod('experoner_ourteam_autoplay_speed','1000'),
        'img_autoplay' => get_theme_mod('experoner_featured_slider_autoplay', true),
        'img_autoplayspped' => get_theme_mod('experoner_featured_slider_autoplay_speed','1000'),
        'testonomial_autoplay' => get_theme_mod('experoner_testonomial_section_autoplay', true),
        'testonomial_autoplayspped' => get_theme_mod('experoner_testonomial_section_autoplay_speed','1000'),
    );
    wp_localize_script( 'main-js', 'main_vars', $main_js_data );
}
add_action( 'wp_enqueue_scripts', 'experoner_main_js' );

function experoner_admin_script_style() {
	 wp_enqueue_script( 'experoner-recommended-plugins', get_template_directory_uri() . '/framework/admin.js', array( 'jquery' ), false, false );
}
add_action('admin_enqueue_scripts', 'experoner_admin_script_style');

add_action( 'admin_notices', 'experoner_admin_notice_demo_data' );
function experoner_admin_notice_demo_data() {
	if( !empty( $_GET['status'] ) && $_GET['status'] == 'experoner_hide_msg' ){
		update_option( 'experoner_hide_msg', true );
	}

	$status = get_option( 'experoner_hide_msg' );
	if( $status == true ){
		return;
	} 

	$recommended_plugins = apply_filters( 'experoner_plugins', $plugins = array() );
	if( empty( $recommended_plugins ) ){
		return;
	}
	$my_theme = wp_get_theme();
	$theme_name = $my_theme->get( 'Name' );
	$nonce = wp_create_nonce("experoner_install_plugins");
	?>
	 <div class="updated notice notice-get-started-class is-dismissible" data-notice="get_started">
                <div class="experoner-getting-started-notice clearfix">
                    <div class="experoner-theme-screenshot">
                        <img src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png" class="screenshot" alt="<?php esc_attr_e( 'Theme Screenshot', 'experoner' ); ?>" />
                    </div><!-- /.experoner-theme-screenshot -->
                    <div class="theme-info-wrapper">
				        <?php 
				        echo '<strong style="font-size: 20px; padding-bottom: 10px; display: block;">';
						
				        printf(
				        	esc_html__( 'Thank you for installing experoner', 'experoner' ),
				        	esc_attr($theme_name)
				        ); 
				        echo '</strong>';
				        echo '<p>' . esc_html__( "It comes with prebuild templates so that you don't have to build it from the start. Clicking the button below will install all the recommended plugins for this theme." , 'experoner' ) . '</p>';
				        ?>

				        <div class="button_wrapper_theme" style="margin-top: 20px;">
					        <a 
					        href="javascript:void(0)" 
					        class="button button-primary button-hero experoner_install_plugins" 
					        data-nonce="<?php echo esc_attr( $nonce ); ?>"
					        data-redirect="<?php echo esc_url( admin_url( 'themes.php?page=one-click-demo-import' ) ); ?>"
					        >
					        <i class="fas fa-sync fa-spin" style="display: none;"></i>
					        <span><?php esc_html_e( 'Get Started', 'experoner' ) ?></span>
					    	</a>

					        <a 
					        href="<?php echo esc_url( admin_url('/?status=experoner_hide_msg') ); ?>" 
					        class="button button-default button-hero experoner_dismiss" ><?php esc_html_e( 'Close', 'experoner' ) ?></a>
				        </div>
			        </div>   
                </div>
            </div>    
    <?php
}
add_filter( 'experoner_plugins', function(){

	$plugins = array(
		array(
			'slug' => 'one-click-demo-import/one-click-demo-import.php',
			'zip'  => 'one-click-demo-import'
		),
		'reviewexchanger-demo-importer' => array(
			'slug' => 'reviewexchanger-demo-importer/reviewexchanger-demo-importer.php',
			'zip' => 'reviewexchanger-demo-importer'
		),	
	);
	return $plugins;
});
add_filter( 'ocdi/regenerate_thumbnails_in_content_import', '__return_false' );
function experoner_ocdi_change_time_of_single_ajax_call() {
    return 10;
}
add_filter( 'ocdi/time_for_one_ajax_call', 'experoner_ocdi_change_time_of_single_ajax_call' );
